@@ -144,6 +144,7 @@ class Base(CremeEntity):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self._lines_cache = {}  # Key: Line class ; Value: Lines instances (list)
+        self._address_auto_copy = True
 
     def __str__(self):
         return self.name
@@ -266,6 +267,7 @@ class Base(CremeEntity):
 
         return credit_notes
 
+    # TODO: remove "source" argument?
     def generate_number(self, source=None):
         # Lazy loading of number generators
         from creme.billing.registry import algo_registry
@@ -344,10 +346,13 @@ class Base(CremeEntity):
         self.source = source.source
         self.target = source.target
 
-        if self.generate_number_in_create:
-            self.generate_number(source.source)
-        else:
-            self.number = ''
+        # if self.generate_number_in_create:
+        #     self.generate_number(source.source)
+        # else:
+        #     self.number = ''
+        self.number = ''
+
+        self._address_auto_copy = False
 
     def _copy_relations(self, source):
         from ..registry import relationtype_converter
@@ -394,6 +399,8 @@ class Base(CremeEntity):
 
     # TODO: Can not we really factorise with clone()
     def build(self, template):
+        self._address_auto_copy = False
+
         self._build_object(template)
         self._post_save_clone(template)  # Copy addresses
         self._post_clone(template)  # Copy lines
@@ -493,7 +500,8 @@ class Base(CremeEntity):
                 type_id=REL_SUB_BILL_RECEIVED, object_entity=target,
             )
 
-            self._create_addresses()
+            if self._address_auto_copy:
+                self._create_addresses()
         else:  # Edition
             self.invalidate_cache()
 
