@@ -6,6 +6,7 @@ from functools import partial
 
 from django.contrib.contenttypes.models import ContentType
 from django.db.models.query_utils import Q
+from django.test.utils import override_settings
 from django.urls import reverse
 from django.utils.encoding import force_str  # force_text
 from django.utils.timezone import now
@@ -78,19 +79,20 @@ class ConvertTestCase(_BillingTestCase):
     @skipIfCustomQuote
     @skipIfCustomInvoice
     def test_convert01(self):
-        self.login()
+        user = self.login()
 
         currency = Currency.objects.create(
             name='Berry', local_symbol='B',
             international_symbol='BB', is_custom=True,
         )
 
-        create_orga = partial(Organisation.objects.create, user=self.user)
+        create_orga = partial(Organisation.objects.create, user=user)
         source = create_orga(name='Source Orga')
+        self._set_managed(source)
         target = create_orga(name='Target Orga')
 
         create_address = Address.objects.create
-        target.billing_address = b_addr = create_address(
+        target.billing_address = create_address(
             name='Billing address 01',
             address='BA1 - Address', po_box='BA1 - PO box',
             zipcode='BA1 - Zip code', city='BA1 - City',
@@ -98,7 +100,7 @@ class ConvertTestCase(_BillingTestCase):
             state='BA1 - State', country='BA1 - Country',
             owner=target,
         )
-        target.shipping_address = s_addr = create_address(
+        target.shipping_address = create_address(
             name='Shipping address 01',
             address='SA1 - Address', po_box='SA1 - PO box',
             zipcode='SA1 - Zip code', city='SA1 - City',
@@ -108,16 +110,28 @@ class ConvertTestCase(_BillingTestCase):
         )
         target.save()
 
+        address_count = Address.objects.count()
+
         quote = self.create_quote('My Quote', source, target, currency)
+        self.assertTrue(quote.number)
+
         quote.additional_info = AdditionalInformation.objects.all()[0]
         quote.payment_terms = PaymentTerms.objects.all()[0]
         quote.payment_info = PaymentInformation.objects.create(
             organisation=source, name='Bank details', is_default=True,
         )
         quote.save()
+        self.assertEqual(address_count + 2, Address.objects.count())
+
+        quote_b_addr = quote.billing_address
+        quote_b_addr.zipcode += ' (Quote)'
+        quote_b_addr.save()
+
+        quote_s_addr = quote.shipping_address
+        quote_s_addr.zipcode += ' (Quote)'
+        quote_s_addr.save()
 
         self.assertFalse(Invoice.objects.count())
-
         self._convert(200, quote, 'invoice')
 
         invoices = Invoice.objects.all()
@@ -130,6 +144,7 @@ class ConvertTestCase(_BillingTestCase):
             ),
             invoice.name,
         )
+        self.assertFalse(invoice.number)  # Not copied
 
         today = date.today()
         self.assertEqual(today, invoice.issuing_date)
@@ -149,20 +164,25 @@ class ConvertTestCase(_BillingTestCase):
         self.assertRelationCount(1, target,  REL_SUB_CUSTOMER_SUPPLIER, object_entity=source)
 
         # Addresses are cloned
+        self.assertEqual(address_count + 4, Address.objects.count())
+
         billing_address = invoice.billing_address
         self.assertIsInstance(billing_address, Address)
-        self.assertEqual(invoice,     billing_address.owner)
-        self.assertEqual(b_addr.name, billing_address.name)
-        self.assertEqual(b_addr.city, billing_address.city)
+        self.assertEqual(invoice,              billing_address.owner)
+        self.assertEqual(quote_b_addr.name,    billing_address.name)
+        self.assertEqual(quote_b_addr.city,    billing_address.city)
+        self.assertEqual(quote_b_addr.zipcode, billing_address.zipcode)
 
         shipping_address = invoice.shipping_address
         self.assertIsInstance(shipping_address, Address)
-        self.assertEqual(invoice,           shipping_address.owner)
-        self.assertEqual(s_addr.name,       shipping_address.name)
-        self.assertEqual(s_addr.department, shipping_address.department)
+        self.assertEqual(invoice,                 shipping_address.owner)
+        self.assertEqual(quote_s_addr.name,       shipping_address.name)
+        self.assertEqual(quote_s_addr.department, shipping_address.department)
+        self.assertEqual(quote_s_addr.zipcode,    shipping_address.zipcode)
 
     @skipIfCustomQuote
     @skipIfCustomSalesOrder
+    @override_settings(SALESORDER_NUMBER_PREFIX='ORD')
     def test_convert02(self):
         "SalesOrder + not superuser."
         self.login(is_superuser=False, allowed_apps=['billing', 'persons'])
@@ -181,11 +201,17 @@ class ConvertTestCase(_BillingTestCase):
             set_type=SetCredentials.ESET_OWN,
         )
 
-        quote = self.create_quote_n_orgas('My Quote')[0]
+        source, target = self.create_orgas()
+        # We set up to generate number
+        self._set_managed(source)
 
+        quote = self.create_quote('My Quote', source=source, target=target)
         self._convert(200, quote, 'sales_order')
         self.assertEqual(0, Invoice.objects.count())
-        self.assertEqual(1, SalesOrder.objects.count())
+
+        orders = SalesOrder.objects.all()
+        self.assertEqual(1, len(orders))
+        self.assertEqual('ORD1', orders[0].number)
 
     @skipIfCustomQuote
     @skipIfCustomSalesOrder
