@@ -10,8 +10,14 @@ from django.urls import reverse
 from django.utils.translation import gettext as _
 
 from creme.creme_core.auth import EntityCredentials
+from creme.creme_core.core.entity_cell import EntityCellRegularField
 from creme.creme_core.gui import actions
-from creme.creme_core.models import Currency, SetCredentials
+from creme.creme_core.gui.custom_form import FieldGroupList
+from creme.creme_core.models import (
+    Currency,
+    CustomFormConfigItem,
+    SetCredentials,
+)
 from creme.persons.constants import REL_SUB_PROSPECT
 from creme.persons.tests.base import (
     skipIfCustomAddress,
@@ -20,6 +26,8 @@ from creme.persons.tests.base import (
 
 from ..actions import ExportQuoteAction
 from ..constants import REL_SUB_BILL_ISSUED, REL_SUB_BILL_RECEIVED
+from ..custom_forms import QUOTE_CREATION_CFORM
+from ..forms.base import BillingSourceSubCell, BillingTargetSubCell
 from ..models import QuoteStatus, SettlementTerms, SimpleBillingAlgo
 from .base import (
     Address,
@@ -169,6 +177,44 @@ class QuoteTestCase(_BillingTestCase):
         quote, source, target = self.create_quote_n_orgas('My Quote', number=number)
         self.assertEqual(number, quote.number)
 
+    def test_createview04(self):
+        "The field 'number' is not in the form."
+        self.login()
+
+        cfci = CustomFormConfigItem.objects.get(
+            descriptor_id=QUOTE_CREATION_CFORM.id,
+            role=None,
+            superuser=False,
+        )
+        cfci.store_groups(FieldGroupList.from_cells(
+            model=Quote,
+            data=[
+                {
+                    'name': _('General information'),
+                    'cells': [
+                        (EntityCellRegularField, {'name': 'user'}),
+                        (EntityCellRegularField, {'name': 'name'}),
+                        (EntityCellRegularField, {'name': 'discount'}),
+                        (EntityCellRegularField, {'name': 'currency'}),
+                        (EntityCellRegularField, {'name': 'status'}),
+
+                        BillingSourceSubCell(model=Quote).into_cell(),
+                        BillingTargetSubCell(model=Quote).into_cell(),
+                    ],
+                },
+            ],
+            cell_registry=QUOTE_CREATION_CFORM.build_cell_registry(),
+            allowed_extra_group_classes=(*QUOTE_CREATION_CFORM.extra_group_classes,)
+        ))
+        cfci.save()
+
+        response = self.assertGET200(reverse('billing__create_quote'))
+
+        with self.assertNoException():
+            fields = response.context['form'].fields
+
+        self.assertNotIn('number', fields)
+
     def test_create_related01(self):
         user = self.login()
 
@@ -608,7 +654,8 @@ class QuoteTestCase(_BillingTestCase):
 
     @skipIfCustomAddress
     @skipIfCustomServiceLine
-    def test_clone(self):
+    def test_clone01(self):
+        "Organisation not managed => number is set to '0'."
         user = self.login()
         source, target = self.create_orgas(user=user)
 
@@ -624,6 +671,7 @@ class QuoteTestCase(_BillingTestCase):
         quote = self.create_quote(
             'Quote001', source, target,
             # status=status,
+            number='12',
         )
         quote.acceptation_date = date.today()
         quote.save()
@@ -637,6 +685,7 @@ class QuoteTestCase(_BillingTestCase):
 
         self.assertIsNone(cloned.acceptation_date)
         # self.assertTrue(cloned.status.is_default) TODO
+        self.assertEqual('0', cloned.number)
 
         self.assertNotEqual(quote, cloned)  # Not the same pk
         self.assertEqual(source, cloned.source)
@@ -654,6 +703,19 @@ class QuoteTestCase(_BillingTestCase):
         self.assertEqual(b_addr.name, billing_address.name)
         self.assertEqual(b_addr.city, billing_address.city)
 
+    def test_clone02(self):
+        "Organisation is managed => number is generated (but only once BUGFIX)."
+        self.login()
+
+        source, target = self.create_orgas()
+        self._set_managed(source)
+
+        quote = self.create_quote('My Quote', source=source, target=target)
+        self.assertEqual('DE1', quote.number)
+
+        cloned = quote.clone()
+        self.assertEqual('DE2', cloned.number)
+
     def test_num_queries(self):
         """Avoid the queries about line sa creation
         (because these queries can be really slow with a lot of entities)
