@@ -140,7 +140,9 @@ class JSONField(fields.CharField):
     default_error_messages = {
         'invalidformat':    _('Invalid format'),
         'invalidtype':      _('Invalid type'),
-        'doesnotexist':     _('This entity does not exist.'),
+        'doesnotexist':     _('This entity does not exist.'),  # TODO: 'An entity ...' ?
+        'isdeleted':        _('«%(entity)s» is in the trash.'),
+        'isexcluded':       _('«%(entity)s» violates the constraints.'),
 
         # Used by child classes
         'entityrequired':   _('The entity is required.'),
@@ -291,7 +293,9 @@ class JSONField(fields.CharField):
             assert issubclass(model, CremeEntity)
 
             try:
-                entity = model.objects.get(is_deleted=False, pk=entity_pk)
+                # TODO: use filter(..).first() if we allow extra Q filter
+                # entity = model.objects.get(is_deleted=False, pk=entity_pk)
+                entity = model.objects.get(pk=entity_pk)
             except model.DoesNotExist as e:
                 raise ValidationError(
                     self.error_messages['doesnotexist'],
@@ -301,11 +305,19 @@ class JSONField(fields.CharField):
                     },
                     code='doesnotexist',
                 ) from e
+            else:
+                if entity.is_deleted:
+                    raise ValidationError(
+                        self.error_messages['isdeleted'],
+                        code='isdeleted',
+                        params={'entity': entity.allowed_str(self._user)},
+                    )
 
         return entity
 
     def _entity_queryset(self, model, qfilter=None):
-        query = model.objects.filter(is_deleted=False)
+        # query = model.objects.filter(is_deleted=False)
+        query = model.objects.all()
 
         if qfilter is not None:
             query = query.filter(qfilter)
@@ -313,14 +325,35 @@ class JSONField(fields.CharField):
         return query
 
     def _clean_entity_from_model(self, model, entity_pk, qfilter=None):
-        try:
-            return self._entity_queryset(model, qfilter).get(pk=entity_pk)
-        except model.DoesNotExist as e:
-            if self.required:
+        # try:
+        #     return self._entity_queryset(model, qfilter).get(pk=entity_pk)
+        # except model.DoesNotExist as e:
+        #     if self.required:
+        #         raise ValidationError(
+        #             self.error_messages['doesnotexist'],
+        #             code='doesnotexist',
+        #         ) from e
+        entity = self._entity_queryset(model, qfilter).filter(pk=entity_pk).first()
+        if entity is None:
+            if qfilter:
+                entity = self._entity_queryset(model).filter(pk=entity_pk).first()
+                if entity is not None:
+                    raise ValidationError(
+                        self.error_messages['isexcluded'],
+                        code='isexcluded',
+                        params={'entity': entity.allowed_str(self._user)},
+                    )
+
+            raise ValidationError(self.error_messages['doesnotexist'], code='doesnotexist')
+        else:
+            if entity.is_deleted:
                 raise ValidationError(
-                    self.error_messages['doesnotexist'],
-                    code='doesnotexist',
-                ) from e
+                    self.error_messages['isdeleted'],
+                    code='isdeleted',
+                    params={'entity': entity.allowed_str(self._user)},
+                )
+
+            return entity
 
     def _value_from_unjsonfied(self, data):
         "Build the field value from deserialized data."
@@ -597,10 +630,13 @@ class MultiGenericEntityField(GenericEntityField):
 
         # Build the list of entities (ignore invalid entries)
         for ct_id, ctype_entity_pks in entities_by_ctype.items():
-            ctype_entities = self._clean_ctype(ct_id).model_class() \
-                                                     .objects \
-                                                     .filter(is_deleted=False) \
-                                                     .in_bulk(ctype_entity_pks)
+            # ctype_entities = self._clean_ctype(ct_id).model_class() \
+            #                                          .objects \
+            #                                          .filter(is_deleted=False) \
+            #                                          .in_bulk(ctype_entity_pks)
+            ctype_entities = self._clean_ctype(ct_id) \
+                                 .get_all_objects_for_this_type() \
+                                 .in_bulk(ctype_entity_pks)
 
             if not all(pk in ctype_entities for pk in ctype_entity_pks):
                 raise ValidationError(
@@ -608,6 +644,15 @@ class MultiGenericEntityField(GenericEntityField):
                     code='doesnotexist',
                 )
 
+            # TODO: factorise
+            for entity in ctype_entities.values():
+                if entity.is_deleted:
+                    raise ValidationError(
+                        self.error_messages['isdeleted'],
+                        code='isdeleted',
+                        params={'entity': entity.allowed_str(self._user)},
+                    )
+
             entities_map.update(ctype_entities)
 
         if not entities_map:
@@ -787,8 +832,9 @@ class MultiRelationEntityField(RelationEntityField):
             ctype = ContentType.objects.get_for_id(ctype_pk)
         except ContentType.DoesNotExist as e:
             raise ValidationError(
-                self.error_messages['ctypedoesnotexist'],
-                code='ctypedoesnotexist',
+                # self.error_messages['ctypedoesnotexist'],
+                # code='ctypedoesnotexist',
+                str(e)
             ) from e
 
         return ctype, []
@@ -862,17 +908,27 @@ class MultiRelationEntityField(RelationEntityField):
         for ctype, entity_pks in ctypes_cache.values():
             ctype_entities = {
                 entity.pk: entity
-                for entity in ctype.model_class()
-                                   .objects
-                                   .filter(is_deleted=False, pk__in=entity_pks)
+                # for entity in ctype.model_class()
+                #                    .objects
+                #                    .filter(is_deleted=False, pk__in=entity_pks)
+                for entity in ctype.get_all_objects_for_this_type(pk__in=entity_pks)
             }
 
             if not all(entity_pk in ctype_entities for entity_pk in entity_pks):
                 raise ValidationError(
                     self.error_messages['doesnotexist'],
                     code='doesnotexist',
+                    # TODO: params={'entity_id': ...} ?
                 )
 
+            for entity in ctype_entities.values():
+                if entity.is_deleted:
+                    raise ValidationError(
+                        self.error_messages['isdeleted'],
+                        code='isdeleted',
+                        params={'entity': entity.allowed_str(self._user)},
+                    )
+
             entities_cache.update(ctype_entities)
 
         self._check_entities_perms(entities_cache.values())
@@ -1035,7 +1091,8 @@ class CreatorEntityField(EntityCredsJSONField):
     def _value_to_jsonifiable(self, value):
         if isinstance(value, int):
             if not self._entity_queryset(
-                self.model, self.q_filter_query,
+                self.model,
+                # self.q_filter_query,
             ).filter(pk=value).exists():
                 raise ValueError(f'No such entity with id={value}.')
 
@@ -1212,6 +1269,13 @@ class FilteredEntityTypeField(JSONField):
 
 
 class OptionalField(fields.MultiValueField):
+    """Base class for fields combining a BooleanField & another field, the first
+    one controlling the inhibition of the second one: when the value of the
+    BooleanField is <False>, the value of the second field is ignored.
+
+    Hint: in the child classes, you should probably use a widget inheriting
+          'OptionalWidget'.
+    """
     sub_field = fields.Field
     widget: Type[core_widgets.OptionalWidget] = core_widgets.OptionalWidget
 
@@ -1598,6 +1662,9 @@ class DurationField(fields.MultiValueField):
 
 
 class ChoiceOrCharField(fields.MultiValueField):
+    """Field which combines a ChoiceField & a CharField ; the user can fill the
+    second one if no choice is satisfying.
+    """
     widget = core_widgets.ChoiceOrCharWidget
 
     default_error_messages = {
@@ -1730,6 +1797,7 @@ class CTypeChoiceField(fields.Field):
 
 
 class MultiCTypeChoiceField(CTypeChoiceField):
+    """Multiple version of CTypeChoiceField."""
     widget = core_widgets.UnorderedMultipleChoiceWidget  # Beware: use Choice inner class
 
     def _build_ctype_choices(self, ctypes):
@@ -1770,12 +1838,16 @@ class MultiCTypeChoiceField(CTypeChoiceField):
 
 
 class EntityCTypeChoiceField(CTypeChoiceField):
+    """Version of CTypeChoiceField where all ContentTypes correspond to classes
+    inheriting CremeEntity.
+    """
     def __init__(self, *, ctypes=None, **kwargs):
         ctypes = ctypes or entity_ctypes
         super().__init__(ctypes=ctypes, **kwargs)
 
 
 class MultiEntityCTypeChoiceField(MultiCTypeChoiceField):
+    """Multiple version of EntityCTypeChoiceField."""
     def __init__(self, *, ctypes=None, **kwargs):
         ctypes = ctypes or entity_ctypes
         super().__init__(ctypes=ctypes, **kwargs)
@@ -1792,23 +1864,35 @@ class EnhancedChoiceIterator:
         choices = self.choices
         forced_values = self.forced_values
 
-        for x in (choices() if callable(choices) else choices):
-            if isinstance(x, dict):
-                value = x['value']
-                label = x['label']
-                help_txt = x.get('help', '')
+        # for x in (choices() if callable(choices) else choices):
+        #     if isinstance(x, dict):
+        #         value = x['value']
+        #         label = x['label']
+        #         help_txt = x.get('help', '')
+        #     else:
+        #         value, label = x
+        #         help_txt = ''
+        #
+        #     yield (
+        #         self.choice_cls(
+        #             value=value,
+        #             readonly=(value in forced_values),
+        #             help=help_txt,
+        #         ),
+        #         label,
+        #     )
+        for choice in (choices() if callable(choices) else choices):
+            if isinstance(choice, dict):
+                choice_kwargs = {**choice}
+                value = choice_kwargs['value']
+                label = choice_kwargs.pop('label')
             else:
-                value, label = x
-                help_txt = ''
+                value, label = choice
+                choice_kwargs = {'value': value}
 
-            yield (
-                self.choice_cls(
-                    value=value,
-                    readonly=(value in forced_values),
-                    help=help_txt,
-                ),
-                label,
-            )
+            choice_kwargs['readonly'] = (value in forced_values)
+
+            yield (self.choice_cls(**choice_kwargs), label)
 
 
 class EnhancedMultipleChoiceField(fields.MultipleChoiceField):
@@ -1985,6 +2069,9 @@ class EnhancedModelMultipleChoiceField(mforms.ModelMultipleChoiceField):
 
 
 class ReadonlyMessageField(fields.CharField):
+    """Field made to display a message to the user.
+    POSTed value is ignored, the given default value is always returned.
+    """
     widget = core_widgets.Label
 
     def __init__(self, *, label, initial='', widget=None, return_value=None):
