@@ -2,7 +2,7 @@
 
 ################################################################################
 #    Creme is a free/open-source Customer Relationship Management software
-#    Copyright (C) 2009-2021  Hybird
+#    Copyright (C) 2009-2022  Hybird
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -870,17 +870,16 @@ class MultiEntityCreatorWidget(SelectorList):
                 #     popupUrl=url,
                 #     title=_('Create') if allowed else _("Can't create"),
                 # )
-
-                name = 'create'
+                action_name = 'create'
                 label = self.creation_label or model.creation_label
                 icon = 'add'
                 button_list.add_action(
-                    name=name, label=label, icon=icon,
+                    name=action_name, label=label, icon=icon,
                     enabled=False, hidden=True,
                     title=_('Create') if allowed else _("Can't create"),
                     popupUrl=url,
                 )
-                self.add_action(name=name, label=label, icon=icon, enabled=allowed)
+                self.add_action(name=action_name, label=label, icon=icon, enabled=allowed)
 
         button_list.delegate = delegate
 
@@ -1061,7 +1060,7 @@ class TinyMCEEditor(widgets.Textarea):
         )
         final_attrs['class'] = css_class + widget_type
         final_attrs['widget'] = widget_type
-        final_attrs['basepath'] = 'tiny_mce/'  # See root urls.py
+        final_attrs['basepath'] = 'tiny_mce'  # See root urls.py
 
         return context
 
@@ -1290,7 +1289,8 @@ class DatePeriodWidget(widgets.MultiWidget):
         super().__init__(
             widgets=(
                 widgets.Select(choices=choices, attrs={'class': 'dperiod-type'}),
-                widgets.TextInput(attrs={'class': 'dperiod-value'}),  # TODO: min_value
+                # widgets.TextInput(attrs={'class': 'dperiod-value'}),
+                widgets.NumberInput(attrs={'class': 'dperiod-value', 'min': 1}),
             ),
             attrs=attrs,
         )
@@ -1324,7 +1324,7 @@ class DatePeriodWidget(widgets.MultiWidget):
             logger.exception('DatePeriodWidget.get_context()')
             inverted = False
 
-        context['widget_indices'] = (1, 0) if inverted else (0, 1)
+        context['widget']['indices'] = (1, 0) if inverted else (0, 1)
 
         return context
 
