@@ -543,13 +543,13 @@ def do_has_perm_to(parser, token):
     """{% has_perm_to TYPE OBJECT as VAR %}
     eg: {% has_perm_to change action.creme_entity as has_perm %}
 
-    TYPE: must be in ('create', 'view','change', 'delete', 'link', 'unlink',
-          'create', 'export', 'admin')
-    OBJECT: * TYPE in ('view','change', 'delete', 'unlink') => must be a CremeEntity.
+    TYPE: must be in ('create', 'view', 'change', 'delete', 'link', 'unlink',
+          'export', 'access', 'admin')
+    OBJECT: * TYPE in ('view','change', 'delete', 'unlink') => must be a CremeEntity instance.
             * TYPE='link' => can be a CremeEntity instance or a class inheriting CremeEntity.
-            * TYPE in ('create', 'export') and a class inheriting from
-              CremeEntity OR a ContentType instance.
-            * TYPE='admin' => an app name, like 'creme_core'.
+            * TYPE in ('create', 'export') => can be a CremeEntity instance,
+              a class inheriting CremeEntity or a ContentType instance.
+            * TYPE in ('access', 'admin') => an app name, like "creme_core".
     """
     try:
         # Splitting by None == splitting by spaces.
