@@ -247,7 +247,7 @@ SECRET_KEY = ''
 
 # A list of strings representing the host/domain names that this Django site can serve.
 # You should set this list for security purposes.
-# See: https://docs.djangoproject.com/en/1.8/ref/settings/#allowed-hosts
+# See: https://docs.djangoproject.com/en/3.2/ref/settings/#allowed-hosts
 ALLOWED_HOSTS = '*'
 
 # SITE: URLs / PATHS / ... [END]################################################
@@ -282,6 +282,7 @@ TEMPLATES = [
                 'creme.creme_core.context_processors.get_bricks_manager',
                 'creme.creme_core.context_processors.get_fields_configs',
                 'creme.creme_core.context_processors.get_shared_data',
+                'creme.creme_core.context_processors.get_jqmigrate_mute',
             ],
             'loaders': [
                 # Don't use cached loader when developing (in your local_settings.py)
@@ -386,12 +387,12 @@ INSTALLED_CREME_APPS = [
     #   - tickets
     'creme.recurrents',
 
-    # Manages Invoices, Quotes, SalesOrders & CreditNote entities.
+    # Manages Invoices, Quotes, SalesOrders & CreditNotes entities.
     # BEWARE: needs the app "products".
     'creme.billing',
 
     # Manages Opportunities entities, which represent business opportunities
-    # (typically an Organisation trying to sell Products/Service to another
+    # (typically an Organisation trying to sell Products/Services to another
     # Organisation).
     # BEWARE: needs the app "products".
     # There are extra features if the app "billing" is installed, like new
@@ -714,6 +715,8 @@ CSS_TEXTAREA_LISTVIEW = 'text_area'
 CSS_DEFAULT_HEADER_LISTVIEW = 'hd_cl_lv'
 CSS_DATE_HEADER_LISTVIEW = 'hd_date_cl_lv'
 
+JQUERY_MIGRATE_MUTE = True
+
 # TODO: create a static/css/creme-minimal.css for login/logout ??
 CREME_CORE_CSS = [
     # Name
