@@ -10,10 +10,16 @@ from django.urls import reverse
 from django.utils.translation import gettext as _
 from PIL.Image import open as open_img
 
-from creme.creme_core.models import CustomField, CustomFieldValue, FieldsConfig
+from creme.creme_core.models import (
+    CremePropertyType,
+    CustomField,
+    CustomFieldValue,
+    FieldsConfig,
+    RelationType,
+)
 from creme.creme_core.tests.base import CremeTestCase
 from creme.documents.tests.base import _DocumentsTestCase
-from creme.persons.constants import REL_SUB_EMPLOYED_BY
+from creme.persons.constants import REL_SUB_EMPLOYED_BY, REL_SUB_MANAGES
 from creme.persons.models import Sector
 
 # from ..forms import vcf as vcf_forms
@@ -469,6 +475,37 @@ END:VCARD"""
     def test_add_contact_vcf01(self):
         user = self.login()
 
+        create_ptype = CremePropertyType.objects.smart_update_or_create
+        ptype01 = create_ptype(
+            str_pk='test-prop_fighter', text='Is a fighter',
+        )
+        ptype02 = create_ptype(
+            str_pk='test-prop_bigcorp', text='Is big corp',
+        )
+
+        create_rtype = RelationType.objects.smart_update_or_create
+        rtype = create_rtype(
+            ('test-subject_showcases', 'showcases',       [Contact]),
+            ('test-object_showcases',  'is showcased by', [Organisation]),
+        )[0]
+        ct_incompatible_rtype = create_rtype(
+            ('test-subject_loves', 'is loving',   [Contact]),
+            ('test-object_loves',  'is loved by', [Contact]),
+        )[0]
+        internal_rtype = create_rtype(
+            ('test-subject_leads', 'is leading', [Contact]),
+            ('test-object_leads',  'is lead by', [Organisation]),
+            is_internal=True,
+        )[0]
+        rtype_with_subject_prop = create_rtype(
+            ('test-subject_fights', 'fights',       [Contact],      [ptype01]),
+            ('test-object_fights',  'is fought by', [Organisation]),
+        )[0]
+        rtype_with_object_prop = create_rtype(
+            ('test-subject_pawn', 'is an insignificant pawn of', [Contact]),
+            ('test-object_pawn',  'has pawn',                    [Organisation], [ptype02]),
+        )[0]
+
         contact_count = Contact.objects.count()
         orga_count    = Organisation.objects.count()
 
@@ -481,6 +518,19 @@ EMAIL;TYPE=HOME:email@email.com
 URL;TYPE=HOME:www.url.com
 END:VCARD"""
         fields = self._post_step0(content).context['form'].fields
+
+        with self.assertNoException():
+            rtype_ids = {*fields['relation'].queryset.values_list('id', flat=True)}
+
+        self.assertIn(REL_SUB_EMPLOYED_BY, rtype_ids)
+        self.assertIn(REL_SUB_MANAGES,     rtype_ids)
+        self.assertIn(rtype.id,            rtype_ids)
+        self.assertNotIn(ct_incompatible_rtype.id,   rtype_ids)
+        self.assertNotIn(internal_rtype.id,          rtype_ids)
+        self.assertNotIn(rtype_with_subject_prop.id, rtype_ids)
+        self.assertNotIn(rtype_with_object_prop.id,  rtype_ids)
+
+        # ---
         response = self._post_step1(
             errors=True,
             data={
